import IIIFResource from './IIIFResource.js';
import Sequence from "./Sequence.js";

const TECH = {
    nir: "Technical Photography, Near Infrared Imaging 1000nm",
}
/**
 * @implements IIIFResource
 */
class Manifest {
    id = '';
    #type = 'sc:Manifest';
    #label = '';
    resourceId = '';
    /**
     * @var {Sequence[]}
     */
    sequences = [];

    constructor(IIIFApiVersion, baseURL) {
        this.context = `https://iiif.io/api/presentation/${IIIFApiVersion}/context.json`;
        this.BASE_URL = baseURL;
    }
    /**
     * @param {Sequence} sequence The Sequence object
     */
    addSequence(sequence) {
        this.sequences.push(sequence.toObject());
    }
    /**
     * @param {string} resourceId From the request
     */
    generateID(resourceId) {
        this.id = `${this.BASE_URL}/${resourceId}/manifest` ;
        this.resourceId = resourceId;
    }
    /**
     * Create IIIF label for this manifest
     */
    generateLabel() {
        this.#label = `P.Herc. ${this.resourceId.split('-')[1]}`;
    }
    /**
     * Object representation of this
     * manifest
     * 
     * @todo Implement
     * @returns {object}
     */
    toObject() {
        return {
            "@context" : this.context,
            "@id" : this.id,
            "@type" : this.#type,
            label : this.#label,
            sequences: this.sequences,
        }
    }
}

export default Manifest;